==> mediawiki-1.17.4.tar.gz: mediawiki-1.17.4/languages/messages/MessagesPi.php <==
<?php
/** Pali (पािऴ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Vibhijain
 */

$digitTransformTable = array(
	'0' => '०', # &#x0966;
	'1' => '१', # &#x0967;
	'2' => '२', # &#x0968;
	'3' => '३', # &#x0969;
	'4' => '४', # &#x096a;
	'5' => '५', # &#x096b;
	'6' => '६', # &#x096c;
	'7' => '७', # &#x096d;
	'8' => '८', # &#x096e;
	'9' => '९', # &#x096f;
);

$messages = array(
# Dates
'january'   => 'ज्यानुवरी',
'february'  => 'फ़रवरी',
'march'     => 'मार्च',
'april'     => 'अप्रैल',
'may_long'  => 'मई',
'june'      => 'जून',
'july'      => 'जुलाई',
'august'    => 'अगस्त',
'september' => 'सेप्टेम्बर',
'october'   => 'ओक्टोबर',
'november'  => 'नवम्बर',
'december'  => 'दिसम्बर',

'article' => 'लेख पत्त',

'searchbutton'  => 'खोज',
'searcharticle' => 'गच्छामि',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'पमुख पत्त',
'mainpage-description' => 'पमुख पत्त',

# Book sources
'booksources-go' => 'गच्छामि',

# Special:AllPages
'allarticles'    => 'सब्ब लेखा',
'allpagessubmit' => 'गच्छामि',

# Namespace 8 related
'allmessagesname' => 'नाम',

# EXIF tags
'exif-gpslatitude'  => 'अक्षांश',
'exif-gpslongitude' => 'देशान्तर',

'exif-sensingmethod-1' => 'अपरिभाषित',

);

==> mediawiki_1.18.1.orig.tar.gz: mediawiki-1.18.1/languages/messages/MessagesPi.php <==
<?php
/** Pali (पािऴ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Vibhijain
 */

$namespaceNames = array(
	NS_MEDIA            => 'मीडिया',
	NS_SPECIAL          => 'विसेस',
	NS_TALK             => 'सम्भासित',
	NS_USER             => 'अवयव',
	NS_USER_TALK        => 'अवयव_सम्भासित',
	NS_PROJECT_TALK     => '$1_सम्भासित',
	NS_FILE             => 'पटिमा',
	NS_FILE_TALK        => 'पटिमा_सम्भासित',
	NS_MEDIAWIKI        => 'मीडियाविकि',
	NS_MEDIAWIKI_TALK   => 'मीडियाविकि_सम्भासित',
	NS_TEMPLATE         => 'पटिरूप',
	NS_TEMPLATE_TALK    => 'पटिरूप_सम्भासित',
	NS_HELP             => 'अवस्सय',
	NS_HELP_TALK        => 'अवस्सय_सम्भासित',
	NS_CATEGORY         => 'विभाग',
	NS_CATEGORY_TALK    => 'विभाग_सम्भासित',
);

$digitTransformTable = array(
	'0' => '०', # &#x0966;
	'1' => '१', # &#x0967;
	'2' => '२', # &#x0968;
	'3' => '३', # &#x0969;
	'4' => '४', # &#x096a;
	'5' => '५', # &#x096b;
	'6' => '६', # &#x096c;
	'7' => '७', # &#x096d;
	'8' => '८', # &#x096e;
	'9' => '९', # &#x096f;
);

$messages = array(
# Dates
'january'   => 'ज्यानुवरी',
'february'  => 'फ़रवरी',
'march'     => 'मार्च',
'april'     => 'अप्रैल',
'may_long'  => 'मई',
'june'      => 'जून',
'july'      => 'जुलाई',
'august'    => 'अगस्त',
'september' => 'सेप्टेम्बर',
'october'   => 'ओक्टोबर',
'november'  => 'नवम्बर',
'december'  => 'दिसम्बर',

'article' => 'लेख पत्त',

'searchbutton'  => 'खोज',
'searcharticle' => 'गच्छामि',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'पमुख पत्त',
'mainpage-description' => 'पमुख पत्त',

# Book sources
'booksources-go' => 'गच्छामि',

# Special:AllPages
'allarticles'    => 'सब्ब लेखा',
'allpagessubmit' => 'गच्छामि',

# Namespace 8 related
'allmessagesname' => 'नाम',

# EXIF tags
'exif-gpslatitude'  => 'अक्षांश',
'exif-gpslongitude' => 'देशान्तर',

'exif-sensingmethod-1' => 'अपरिभाषित',

);
